//
//  PRTransforms.h
//  PRICE
//
//  Created by Riccardo Mottola on Mon Dec 23 2002.
//  Copyright (c) 2002-2003-2004 Carduus. All rights reserved.
//
// This application is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
// This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.


#import <AppKit/AppKit.h>
#import "PRImage.h"


@interface PRTransforms : NSObject
{

}

- (PRImage *)transposeImage:(PRImage *)srcImage;
- (PRImage *)rotateImage90:(PRImage *)srcImage;
- (PRImage *)rotateImage180:(PRImage *)srcImage;
- (PRImage *)rotateImage270:(PRImage *)srcImage;
- (PRImage *)flipImageVert:(PRImage *)srcImage;
- (PRImage *)flipImageHoriz:(PRImage *)srcImage;

@end
